@@ -447,85 +447,11 @@ $VERSION = eval $VERSION;
 
 our $macros_xs = pp_line_numbers(__LINE__, <<'EOF');
 #include "pdlperl.h"
-
-#define PDL_XS_PREAMBLE(nret) \
-  char *objname = "PDL"; /* XXX maybe that class should actually depend on the value set \
-                            by pp_bless ? (CS) */ \
-  HV *bless_stash = 0; \
-  SV *parent = 0; \
-  int   nreturn = (nret); \
-  (void)nreturn; \
-  PDL_COMMENT("Check if you can get a package name for this input value.  ") \
-  PDL_COMMENT("It can be either a PDL (SVt_PVMG) or a hash which is a     ") \
-  PDL_COMMENT("derived PDL subclass (SVt_PVHV)                            ") \
-  do { \
-    if (SvROK(ST(0)) && ((SvTYPE(SvRV(ST(0))) == SVt_PVMG) || (SvTYPE(SvRV(ST(0))) == SVt_PVHV))) { \
-      parent = ST(0); \
-      if (sv_isobject(parent)){ \
-          bless_stash = SvSTASH(SvRV(ST(0))); \
-          objname = HvNAME((bless_stash));  PDL_COMMENT("The package to bless output vars into is taken from the first input var") \
-      } \
-    } \
-  } while (0)
-
-static inline pdl *PDL_XS_pdlinit(pTHX_ char *objname, HV *bless_stash, SV *to_push, char *method, SV **svp) {
-  dSP;
-  pdl *ret;
-  if (strcmp(objname,"PDL") == 0) { PDL_COMMENT("shortcut if just PDL")
-     ret = PDL->pdlnew();
-     if (!ret) PDL->pdl_barf("Error making null pdl");
-     if (svp) {
-       *svp = sv_newmortal();
-       PDL->SetSV_PDL(*svp, ret);
-       if (bless_stash) *svp = sv_bless(*svp, bless_stash);
-     }
-  } else {
-     PUSHMARK(SP);
-     XPUSHs(to_push);
-     PUTBACK;
-     perl_call_method(method, G_SCALAR);
-     SPAGAIN;
-     SV *sv = POPs;
-     PUTBACK;
-     ret = PDL->SvPDLV(sv);
-     if (svp) *svp = sv;
-  }
-  return ret;
-}
-#define PDL_XS_PERLINIT_init() \
-  PDL_XS_pdlinit(aTHX_ objname, bless_stash, sv_2mortal(newSVpv(objname, 0)), "initialize", NULL)
-#define PDL_XS_PERLINIT_initsv(sv) \
-  PDL_XS_pdlinit(aTHX_ objname, bless_stash, sv_2mortal(newSVpv(objname, 0)), "initialize", &sv)
-#define PDL_XS_PERLINIT_copy() \
-  PDL_XS_pdlinit(aTHX_ objname, bless_stash, parent, "copy", NULL)
-#define PDL_XS_PERLINIT_copysv(sv) \
-  PDL_XS_pdlinit(aTHX_ objname, bless_stash, parent, "copy", &sv)
-
-#define PDL_XS_RETURN(clause1) \
-    if (nreturn) { \
-      if (nreturn > 0) EXTEND (SP, nreturn); \
-      clause1; \
-      XSRETURN(nreturn); \
-    } else { \
-      XSRETURN(0); \
-    }
-
-#define PDL_IS_INPLACE(in) ((in)->state & PDL_INPLACE)
-#define PDL_XS_INPLACE(in, out, whichinit) \
-    if (PDL_IS_INPLACE(in)) { \
-        if (out ## _SV) barf("inplace input but different output given"); \
-        out ## _SV = sv_newmortal(); \
-        in->state &= ~PDL_INPLACE; PDL_COMMENT("unset") \
-        out = in; \
-        PDL->SetSV_PDL(out ## _SV,out); \
-    } else \
-        out = out ## _SV ? PDL_CORE_(SvPDLV)(out ## _SV) : \
-          PDL_XS_PERLINIT_ ## whichinit ## sv(out ## _SV);
 EOF
 
 our $header_c = pp_line_numbers(__LINE__, <<'EOF');
 /*
- * THIS FILE WAS GENERATED BY PDL::PP! Do not modify!
+ * THIS FILE WAS GENERATED BY PDL::PP from %s! Do not modify!
  */
 
 #define PDL_COMMENT(comment)
@@ -826,7 +752,7 @@ sub printxsc {
   my $text = join '',@_;
   if (defined $file) {
     (my $mod_underscores = $::PDLMOD) =~ s#::#_#g;
-    $text = join '', sprintf($PDL::PP::header_c, $mod_underscores), $::PDLXSC_header//'', $text;
+    $text = join '', sprintf($PDL::PP::header_c, $0, $mod_underscores), $::PDLXSC_header//'', $text;
     _write_file($file, $text);
   } else {
     $::PDLXSC .= $text;
@@ -844,7 +770,7 @@ sub pp_done {
         $user_boot =~ s/^\s*(.*?)\n*$/  $1\n/ if $user_boot;
         (my $mod_underscores = $::PDLMOD) =~ s#::#_#g;
         my $text = join '',
-          sprintf($PDL::PP::header_c, $mod_underscores),
+          sprintf($PDL::PP::header_c, $0, $mod_underscores),
           $::PDLXSC//'',
           $PDL::PP::macros_xs,
           sprintf($PDL::PP::header_xs, $::PDLMOD, $::PDLOBJ),
@@ -859,7 +785,7 @@ sub pp_done {
         $::FUNCSPOD = $::DOCUMENTED ? "\n\n=head1 FUNCTIONS\n\n=cut\n\n" : '';
         _write_file("$::PDLPREF.pm", join "\n\n", <<EOF, $::PDLBEGIN, $::PDLPM{Top}, $::FUNCSPOD, @::PDLPM{qw(Middle Bot)}, '# Exit with OK status', "1;\n");
 #
-# GENERATED WITH PDL::PP! Don't modify!
+# GENERATED WITH PDL::PP from $0! Don't modify!
 #
 package $::PDLPACK;
 
@@ -1073,8 +999,9 @@ sub indent($$) {
 # This subroutine generates the XS code needed to call the perl 'initialize'
 # routine in order to create new output PDLs
 sub callPerlInit {
-    my ($sv, $callcopy) = @_;
-    "PDL_XS_PERLINIT_".($callcopy ? "copy" : "init").($sv ? "sv($sv)" : "()");
+    my ($sv) = @_;
+    confess "callPerlInit error: \$sv must be defined" if !defined $sv;
+    "PDL_XS_PERLINIT_initsv($sv)";
 }
 
 sub callTypemap {
@@ -1105,13 +1032,13 @@ sub reorder_args {
 # Parameters : $fulldoc
 # Throws     : never
 # Notes      : the signature must have the following form:
-#            : 
+#            :
 #            : =for sig
 #            : <blank>
 #            :   Signature: (<signature can
 #            :                be multiline>)
 #            : <blank>
-#            : 
+#            :
 #            : The two spaces before "Signature" are required, as are
 #            : the parentheses.
 sub extract_signature_from_fulldoc {
@@ -1187,7 +1114,7 @@ $PDL::PP::deftbl =
       #            : the part of the signature that specifies the ndarrays
       # Returns    : a string appropriate for the Pars key
       # Parameters : $fulldoc
-      # Throws     : if there is no signature 
+      # Throws     : if there is no signature
       #            : if there is no extractable Pars section
       #            : if some PDL arguments come after the OtherPars arguments start
       # Notes      : This is meant to be used directly in a Rule. Therefore, it
@@ -1251,19 +1178,19 @@ $PDL::PP::deftbl =
    ################################
    # Other Documentation Handling #
    ################################
-   
+
    # no docs by default
    PDL::PP::Rule::Returns->new("Doc", [], 'Sets the default doc string',
     "\n=for ref\n\ninfo not available\n"),
-   
+
    # try and automate the docs
    # could be really clever and include the sig to see about
    # input/output params, for instance
-   
+
    PDL::PP::Rule->new("BadDoc", [qw(BadFlag Name CopyBadStatusCode?)],
               'Sets the default documentation for handling of bad values',
       sub {
-         my ( $bf, $name, $code ) = @_;
+         my ($bf, $name, $code) = @_;
          my $str;
          if ( not defined($bf) ) {
             $str = "$name does not process bad values.\n";
@@ -1354,11 +1281,11 @@ EOD
    PDL::PP::Rule->new("HaveBroadcasting","HaveThreading", sub {@_}), # compat
    PDL::PP::Rule::Croak->new([qw(P2Child GenericTypes)],
        'Cannot have both P2Child and GenericTypes defined'),
-   PDL::PP::Rule->new([qw(Pars HaveBroadcasting CallCopy GenericTypes DefaultFlow AllFuncHeader RedoDimsFuncHeader)],
+   PDL::PP::Rule->new([qw(Pars HaveBroadcasting GenericTypes DefaultFlow AllFuncHeader RedoDimsFuncHeader)],
 		      ["P2Child","Name","StructName"],
       sub {
         my (undef,$name,$sname) = @_;
-        ("PARENT(); [oca]CHILD();",0,0,[PDL::Types::ppdefs_all()],1,
+        ("PARENT(); [oca]CHILD();",0,[PDL::Types::ppdefs_all()],1,
           "pdl *__it = $sname->pdls[1]; (void) __it;\n",
           "PDL->hdr_childcopy($sname); $sname->dims_redone = 1;\n",
         );
@@ -1472,21 +1399,6 @@ EOD
       sub { PDL::PP::Signature->new('', @_[0,1], join(';', grep defined() && /[^\s;]/, @_[2..$#_])) }),
    PDL::PP::Rule->new("CompStruct", ["CompObj"], sub {$_[0]->getcomp}),
 
- # Set CallCopy flag for simple functions (2-arg with 0-dim signatures)
- #   This will copy the $object->copy method, instead of initialize
- #   for PDL-subclassed objects
- #
-   PDL::PP::Rule->new("CallCopy", ["SignatureObj", "Name"],
-      sub {
-	  my ($sig, $Name, $hasp2c) = @_;
-	  my $noDimmedArgs = $sig->dims_obj->ind_names;
-	  my $noArgs = @{$sig->names};
-	  # Check for 2-arg function with 0-dim signatures
-	  return 0 if !($noDimmedArgs == 0 and $noArgs == 2);
-	  # Check to see if output arg is _not_ explicitly typed:
-	  !$sig->objs->{$sig->names->[1]}{FlagTypeOverride};
-      }),
-
    PDL::PP::Rule->new("InplaceNormalised", ["SignatureObj","Inplace"],
 		      'interpret Inplace and Signature to get input/output',
       # Inplace can be supplied several values
@@ -1531,15 +1443,15 @@ EOD
         }
         [$in, $out];
       }),
-   PDL::PP::Rule->new(["InplaceCode"], [qw(InplaceNormalised CallCopy)],
+   PDL::PP::Rule->new(["InplaceCode"], [qw(InplaceNormalised)],
       'code to implement working inplace',
       # insert code, after the autogenerated xs argument processing code
       # produced by VarArgsXSHdr and AFTER any in HdrCode
       # - this code flags the routine as working inplace,
       sub {
-        my ($arg, $callcopy) = @_;
+        my ($arg) = @_;
         my ($in, $out) = @$arg;
-        "  PDL_XS_INPLACE($in, $out, @{[$callcopy ? 'copy' : 'init']})\n";
+        "  PDL_XS_INPLACE($in, $out)\n";
       }),
    PDL::PP::Rule::Returns::EmptyString->new("InplaceCode", []),
 
@@ -1587,11 +1499,11 @@ EOD
       }),
    PDL::PP::Rule->new("VarArgsXSHdr",
       [qw(Name SignatureObj
-       CallCopy? OtherParsDefaults? ArgOrder? InplaceNormalised?)],
+       OtherParsDefaults? ArgOrder? InplaceNormalised?)],
       'XS code to process input arguments based on supplied Pars argument to pp_def; not done if GlobalNew or PMCode supplied',
       sub {
         my($name,$sig,
-           $callcopy,$otherdefaults,$argorder,$inplace) = @_;
+           $otherdefaults,$argorder,$inplace) = @_;
         $argorder = [reorder_args($sig, $otherdefaults)] if $argorder and !ref $argorder;
         my $optypes = $sig->otherobjs;
         my @args = @{ $argorder || $sig->allnames(1, 1) };
@@ -1629,7 +1541,7 @@ EOD
             exists $otherdefaults->{$x} ? "=$otherdefaults->{$x}" :
             !$out{$x} ? '' :
             $inplace && $x eq $inplace->[1] ? "=$x" :
-            "=".callPerlInit($x."_SV", $callcopy)
+            "=".callPerlInit($x."_SV")
             );
           push @inputdecls, "$ptypes{$x}$x".($inplace && $x eq $inplace->[1] ? "=NO_INIT" : '');
         }
@@ -1641,12 +1553,12 @@ EOD
           push @xsargs, "$x=$x";
           push @inputdecls, "$ptypes{$x}$x".($other{$x} && !exists $otherdefaults->{$x} ? "; { ".callTypemap($x, $ptypes{$x}, $name)."; }" : "=NO_INIT");
         }
-        push @inputdecls, map "$ptypes{$_}$_=".callPerlInit($_."_SV", $callcopy).";", grep $outca{$_}, @args;
+        push @inputdecls, map "$ptypes{$_}$_=".callPerlInit($_."_SV").";", grep $outca{$_}, @args;
         my $defaults_rawcond = $ndefault ? "items == $nin_minus_default" : '';
         my $svdecls = join '', map "\n  $_",
           (map "SV *${_}_SV = ".(
             !$name2cnts{$_} ? 'NULL' :
-            $argorder ? "items > $name2cnts{$_}[1] ? ST($name2cnts{$_}[1]) : ".($other_out{$_} ? "sv_newmortal()" : "NULL") :
+            ($argorder || (defined $otherdefaults->{$_} && !$nout)) ? "items > $name2cnts{$_}[1] ? ST($name2cnts{$_}[1]) : ".($other_out{$_} ? "sv_newmortal()" : "NULL") :
             $name2cnts{$_}[0] == ($name2cnts{$_}[1]//-1) ? "ST($name2cnts{$_}[0])" :
             "(items == $nmaxonstack) ? ST($name2cnts{$_}[0]) : ".
             (!defined $name2cnts{$_}[1] ? ($other_out{$_} ? "sv_newmortal()" : "NULL") :
@@ -1662,7 +1574,7 @@ EOD
               "{ ".callTypemap($_, $ptypes{$_}, $name)."; }\n",
               grep !$argorder && exists $otherdefaults->{$_}, @{$sig->othernames(1, 1)}),
             (map callTypemap($_, $ptypes{$_}, $name).";\n", grep !$already_read{$_}, $sig->names_in),
-            (map +("if (${_}_SV) { ".($argorder ? '' : callTypemap($_, $ptypes{$_}, $name))."; } else ")."$_ = ".callPerlInit($_."_SV", $callcopy).";\n", grep $out{$_} && !$already_read{$_} && !($inplace && $_ eq $inplace->[1]), @args)
+            (map +("if (${_}_SV) { ".($argorder ? '' : callTypemap($_, $ptypes{$_}, $name))."; } else ")."$_ = ".callPerlInit($_."_SV").";\n", grep $out{$_} && !$already_read{$_} && !($inplace && $_ eq $inplace->[1]), @args)
           );
         push @preinit, qq[PDL_XS_PREAMBLE($nretval);] if $nallout;
         push @preinit, qq{if (!(@{[join ' || ', map "(items == $_)", sort keys %valid_itemcounts]}))
@@ -1850,6 +1762,7 @@ sub make_vfn_args {
    PDL::PP::Rule::Returns::NULL->new("WriteBackDataFuncName", "Code"),
    PDL::PP::Rule->new(make_vfn_args("WriteBackData")),
 
+   # CORE21 move this into pdlapi so RedoDims without Code can broadcast
    PDL::PP::Rule->new("DefaultRedoDims",
       ["StructName"],
       sub { "PDL_RETERROR(PDL_err, PDL->redodims_default($_[0]));\n" }),
