@@ -2,19 +2,6 @@
 
 PDL::Lite - minimum PDL module OO loader
 
-=head1 DESCRIPTION
-
-Loads the smallest possible set of modules for
-PDL to work, importing only those functions always defined by
-L<PDL::Core>) into the current namespace
-(C<pdl>, C<piddle>, C<barf> and C<null>).
-This is the absolute minimum set for PDL.
-
-Access to other functions is by method syntax, viz:
-
-  $x = PDL->pdl(1, 2, 3, 4, 5);
-  $x->wibble(42);
-
 =head1 SYNOPSIS
 
  use PDL::Lite; # Is equivalent to the following:
@@ -28,6 +15,22 @@ Access to other functions is by method syntax, viz:
    use PDL::Bad '';
    use PDL::Lvalue;
 
+=head1 DESCRIPTION
+
+Loads the smallest possible set of modules for
+PDL to work, importing only those functions always defined by
+L<PDL::Core>) into the current namespace
+(C<pdl>, C<ndarray>, C<barf> and C<null>).
+This is the absolute minimum set for PDL.
+
+Access to other functions is by method syntax, viz:
+
+  $x = PDL->pdl(1, 2, 3, 4, 5);
+  $x->wibble(42);
+
+Note that unlike L<PDL>, this does I<not> load L<PDL::Math> or
+L<PDL::MatrixOps>, nor any IO modules.
+
 =cut
 
 package PDL::Lite;
